@@ -6,7 +6,6 @@ if ENV.delete('COVERAGE')
   SimpleCov.start do
     enable_coverage :branch
     add_filter "/test/"
-    add_filter "/lib/rack/handler"
     add_group('Missing'){|src| src.covered_percent < 100}
     add_group('Covered'){|src| src.covered_percent == 100}
   end
@@ -38,4 +37,19 @@ class Minitest::Spec
       end
     end
   end
+  
+  def capture_warnings(target)
+    verbose = $VERBOSE
+    warnings = Thread::Queue.new
+    target.define_singleton_method(:warn) do |*args|
+      warnings << args
+    end
+    begin
+      $VERBOSE = true
+      yield warnings
+    ensure
+      $VERBOSE = verbose
+      target.singleton_class.send(:remove_method, :warn)
+    end
+  end
 end
